%  Question box
qstring = 'The authors and sponsors of disclaim any responsibility or liability of any kind associated with the material contained here and make no warrantees, expressed or implied, of any kind, regarding the information or methods contained herein.  Furthermore none of the contents of this tool shall be construed as a recommendation of any patented or proprietary product or application. By using this command language, the user agrees to hold harmless the authors and sponsors from any damages that might result from the use of this program.'
title = 'Disclaimer Use at Own Risk'
str1 = 'Yes'
str2 = 'No'
default = 'No'
choice = questdlg(qstring,title,str1,str2,default)
% Three choices: Yes, No and Close the dialogue box without answering
switch choice
case 'Yes'    % Accept the disclaimer
% READING FILE DATA INTO ARRAYS
[filename, pathname] = uigetfile('*.csv', 'Select JA-10 csv file with photometric data');
source = strcat(pathname, filename);
destination1 = strcat(pathname,'ModifiedJA10-',filename);
destination2 = strcat(pathname,'FlickerJA8-',filename);
cd(pathname);

fileIn = source
fileOut1 = destination1
fileOut2 = destination2

fidIn = fopen(fileIn);
fidOut1 = fopen(fileOut1,'w+');

% Skip first 4 lines of input file
for Nline = 1:4	% Moves input file ahead to line 5
	tline = fgets(fidIn);
end

%Reading in dimmer type from input file header
formatSpec = '%s';
C_text5 = textscan(fidIn,formatSpec,5, 'Delimiter', ',');
fclose(fidIn);
fidIn = fopen(fileIn);

% Skip first 5 lines of input file and read in lighting product information
for Nline = 1:5	% Moves input file ahead to line 5
	tline = fgets(fidIn);
end

C_text6 = textscan(fidIn,formatSpec,5, 'Delimiter', ',');

DimmingType = C_text5{1}{2}
Manufacturer = C_text6{1}{3}
Brand = C_text6{1}{4}
ModelNumber = C_text6{1}{5}

fclose(fidIn);
fidIn = fopen(fileIn);

% ***********Collect information about the test (number of readings, interval rate etc)**********
%  The row and column arguments are zero based, so that row = 0 and col = 0 specify the first value in the file
%  Variable = csvread(filename,row,col,csvRange) reads only the range specified by csvRange 
%  Variable = csvread('csvlist.dat',1,0,[1,0,2,2]) once in M the index of the array starts with 1

Interval = csvread(fileIn,7,1,[7,1,7,1]) % Time period between each recorded measurement (8th row 2nd column)
Duration = csvread(fileIn,8,1,[8,1,8,1]) % Length of total measurement Duration (9th row 2nd column)
N = csvread(fileIn,9,1,[9,1,9,1]) % Number of data points (10th row 2nd column)

fS = (1/Interval) % sampling frequency of recorded data
Nz = floor(Duration/Interval)  % Nz should equal N
FracMeas = csvread(fileIn,11,1,[11,1,11,3])  % fraction of full light (12 th row 2-4 th columns)

% write to ModifiedJA10- file
% fopen - Open file and overwrite 'w'  only applies to output file
fidOut1 = fopen(fileOut1, 'w');

% Writing first 11 lines from source (input) file to destination (output) file 
for Nline = 1:11
	tline = fgets(fidIn);
	fprintf(fidOut1, '%s', tline);
end

% Line 12 echo back Measured fraction from input file into output file
DimmingText = 'Measured fraction of max output' ;
myformat = '%s,%f, %f, %f\r\n';
fprintf(fidOut1, myformat, DimmingText, FracMeas);


% Vectors with 5 elements, CutOffHz - cut off frequencies, and
% FilterIndex - Fourier coefficient number that corresponds to Cut-off frequency

% Cut-off frequency*Duration = Fourier element number corresponding to cut-off frequency

CutOffHz = [1000 400 200 90 40]       
FilterIndex = round(CutOffHz*Duration)
for Hz = 1:5	% 5 cut-off frequencies. See CutOffHz
	% filterindex - how many transform terms allowed before truncation  
	% format of MATLAB transform frequency bins ( 0, 1, N/2, -N/2+1, -N/2+2, -2, -1)
	% filter array has 1s for low frequencies below cut-off frequency term, 
% 0s in middle of array to cut-off high frequencies and 
% 1s at end of end of array for low negative frequency terms 
	FilterArray(:,Hz) = vertcat(ones(FilterIndex(Hz),1), zeros(N-2*FilterIndex(Hz),1), ones(FilterIndex(Hz),1));
end   % Hz loop

% PD - percent dimming 1 = 100% (full output), 2= 20%, 3 = minimum  
% 3 columns of data corresponding to 3 increments of percent dimming

for PD = 1:3	
    M=csvread(fileIn,21,PD,[21,PD,N+20,PD]);  % reading starting on line 22 (csvread uses 0 index for first value)
    F = fft(M);
 
% 5 cut-off frequencies. See CutOffHz ********************
for Hz = 1:5	
	FilteredFourier = FilterArray(:,Hz).*F;	
    
% Store the filtered Fourier coefficients in a N x PD matrix 
	FF(:,Hz) = FilteredFourier;

	InvFF = abs(ifft(FilteredFourier));
    
% Store filtered time domain data in a N x PD matrix
	FFI(:,Hz) = InvFF;
	AM(Hz,PD) = (max(InvFF) - min(InvFF)) /(max(InvFF) + min(InvFF));
    
% percent AM as a fraction,
% Note:  value between 0.000 and 1.000 (change from JA 10 which was between 0 and 100)

end      %Hz loop for each cut-off frequency**********

% Unfiltered Fourier evaluate M directly
	Hz = 6;
	AM(Hz,PD) = (max(M) - min(M)) /(max(M) + min(M));  % AM as a fraction < 1

end     % PD loop with data for each dimming level**************

% Display to screen
display(N)
display(FilterIndex)
display(CutOffHz)
display(FracMeas)
display(AM)



% print unfiltered amplitude modulation data to file
	UnfilText = 'Unfiltered Amplitude Modulation';
	myformat = '%s, %6.3f, %6.3f, %6.3f\r\n';  % note: only two decimal places for JA8 file
	newData = [AM(6,1), AM(6,2),AM(6,3)];
	fprintf(fidOut1, myformat, UnfilText, newData);

for Hz = 1:5	% Prints filtered amplitude modulation data to output file
myformat = '%s, %6.3f, %6.3f, %6.3f\r\n';  % note: only two decimal places for JA8 file
LabelHz = sprintf('Amplitude Mod  %d Hz cut-off', CutOffHz(Hz));
	newData = [AM(Hz,1), AM(Hz,2),AM(Hz,3)];
fprintf(fidOut1, myformat, LabelHz , newData);
end

% Placeholder for Normalized Modulation and Weighted Amplitude Modulation
myformat = '%s, %8.3f, %8.3f, %8.3f\r\n';  % note: can be much greater than 1.

NMText = 'Reserved for future use';
NM = [0, 0, 0]; % overwrite values with 0's while under development
NorMod = [NM(1), NM(2),NM(3)]
fprintf(fidOut1, myformat, NMText, NorMod);

AMwText = 'Reserved for future use';
AMw = [0, 0,0]; % overwrite values with 0's while under development
AMweighted = [AMw(1), AMw(2), AMw(3)]
fprintf(fidOut1, myformat, AMwText, AMweighted);


% Insert Raw data at end of ModifiedJ10 output file
for Nline = 12:20	% Moves input file ahead to line 21
	tline = fgets(fidIn);
end

Nline = 21;   % print header lines from row 21 of Input file to row 21 of output file
	tline = fgets(fidIn);
	fprintf(fidOut1, '%s', tline);

% read in high frequency photometric data (flicker data)
RawData=csvread(fileIn,21,0,[21,0,N+20,3]); % reading starting on line 22 (csvread uses 0 index for first value)

% transpose and write high frequency photometric data (flicker data) to output file
RawDataT = transpose(RawData);
myformat = '%f, %f, %f, %f\r\n';
	fprintf(fidOut1, myformat, RawDataT);

fclose(fidOut1);
fclose(fidIn);

% JA10 file finished and closed
%***********************************************************

% write to FlickerJA8- file 
fidOut2= fopen(fileOut2, 'w+');
% Column labels in first row of JA8-2016 file for MAEDBS database
A = {'Action';
'Manufacturer';
'Brand';
'ModelNumber';
'LightTech';
'ProductType';
'ConnectionType';
'LightSourceDimmingType';
'Efficacy';
'CCT';
'DUV';
'CRI';
'CRI9';
'StartTime';
'PowerFactor';
'TempTest';
'RatedLife';
'LumenMaint';
'SurvivalRate';
'ProjectedL70';
'DimmingLevel';
'NoiseFull';
'NoiseDimmed';
'FlickerFullUnfiltered';
'FlickerFull1000Hz';
'FlickerFull400Hz';
'FlickerFull200Hz';
'FlickerFull90Hz';
'FlickerFull40Hz';
'FlickerDimmedUnfiltered';
'FlickerDimmed1000Hz';
'FlickerDimmed400Hz';
'FlickerDimmed200Hz';
'FlickerDimmed90Hz';
'FlickerDimmed40Hz';
'FlickerMinUnfiltered';
'FlickerMin1000Hz';
'FlickerMin400Hz';
'FlickerMin200Hz';
'FlickerMin90Hz';
'FlickerMin40Hz';
'Marking';
'RegulatoryStatus'};

% Transpose labels and print to first row of JA8 file
C = A';
fprintf(fidOut2, '%s,', C{1,1:end-1}) ;
fprintf(fidOut2, '%s\n', C{1,end}) ;


%Fill second row with blanks, equipment tested and flicker (filtered amplitude modulation) data
DataStr = cell(1,23);
DataStr(1,2) = cellstr(Manufacturer);
DataStr(1,3) = cellstr(Brand);
DataStr(1,4) = cellstr(ModelNumber); 
DataStr(1,8) = cellstr(DimmingType);

for PD = 1:3
FlickJA8(PD*6-5) =AM(6,PD);
for Hz = 1:5
FlickJA8((PD-1)*6+Hz+1) =AM(Hz,PD);
end  % Hz loop
end   % PD loop

fprintf(fidOut2, '%s,', DataStr {1,1:end}) ;
fprintf(fidOut2, '%6.2f,', FlickJA8);
fclose(fidOut2);
fclose('all');
case 'No'       % 'No' answer to disclaimer window
fclose('all');
case ''         % Closed disclaimer window without answering question
fclose('all');
end
